==> jato-0.0.2.tar.gz: jato-0.0.2/arch/x86/include/arch/registers_32.h <==
#ifndef X86_REGISTERS_32_H
#define X86_REGISTERS_32_H

#include "vm/types.h"

#include <ucontext.h>	/* for gregset_t */
#include <stdbool.h>
#include <limits.h>

enum machine_reg {
	MACH_REG_EAX,
	MACH_REG_ECX,
	MACH_REG_EDX,
	MACH_REG_EBX,
	MACH_REG_ESI,
	MACH_REG_EDI,

	/* Number of general purpose registers.  */
	NR_GP_REGISTERS,

	MACH_REG_XMM0 = NR_GP_REGISTERS,
	MACH_REG_XMM1,
	MACH_REG_XMM2,
	MACH_REG_XMM3,
	MACH_REG_XMM4,
	MACH_REG_XMM5,
	MACH_REG_XMM6,
	MACH_REG_XMM7,

	/* The above registers are available for register allocator.  */
	NR_REGISTERS,

	MACH_REG_EBP = NR_REGISTERS,
	MACH_REG_ESP,

	/* The above registers are available for get_fixed_var().  */
	NR_FIXED_REGISTERS,

	/* Either-R**-or-E** variants (for 32/64-bit common code). */
	MACH_REG_xAX = MACH_REG_EAX,
	MACH_REG_xCX = MACH_REG_ECX,
	MACH_REG_xDX = MACH_REG_EDX,
	MACH_REG_xBX = MACH_REG_EBX,
	MACH_REG_xSI = MACH_REG_ESI,
	MACH_REG_xDI = MACH_REG_EDI,
	MACH_REG_xBP = MACH_REG_EBP,
	MACH_REG_xSP = MACH_REG_ESP,

	MACH_REG_UNASSIGNED = INT_MAX,
};

#define GPR_VM_TYPE	J_INT

#define NR_CALLER_SAVE_REGS 11
extern enum machine_reg caller_save_regs[NR_CALLER_SAVE_REGS];

const char *reg_name(enum machine_reg reg);

bool reg_supports_type(enum machine_reg reg, enum vm_type type);

struct register_state {
	union {
		unsigned long		regs[6];
		struct {
			unsigned long	eax;
			unsigned long	ebx;
			unsigned long	ecx;
			unsigned long	edi;
			unsigned long	edx;
			unsigned long	esi;
		};
	};
};

#define SAVE_REG(reg, dst)  \
	__asm__ volatile ("movl %%" reg ", %0\n\t" : "=m"(dst))

static inline void save_registers(struct register_state *regs)
{
	SAVE_REG("eax", regs->eax);
	SAVE_REG("ebx", regs->ebx);
	SAVE_REG("ecx", regs->ecx);
	SAVE_REG("edx", regs->edx);
	SAVE_REG("edi", regs->edi);
	SAVE_REG("esi", regs->esi);
}

static inline void
save_signal_registers(struct register_state *regs, gregset_t gregs)
{
        regs->eax = gregs[REG_EAX];
        regs->ebx = gregs[REG_EBX];
        regs->ecx = gregs[REG_ECX];
        regs->edx = gregs[REG_EDX];
        regs->esi = gregs[REG_ESI];
        regs->edi = gregs[REG_EDI];
}

#endif /* X86_REGISTERS_32_H */

==> jato-0.3.tar.gz: jato-0.3/arch/x86/include/arch/registers_32.h <==
#ifndef X86_REGISTERS_32_H
#define X86_REGISTERS_32_H

#include "vm/types.h"

#include <stdbool.h>
#include <limits.h>

enum machine_reg {
	MACH_REG_EAX,
	MACH_REG_ECX,
	MACH_REG_EDX,
	MACH_REG_EBX,
	MACH_REG_ESI,
	MACH_REG_EDI,

	/* Number of general purpose registers.  */
	NR_GP_REGISTERS,

	MACH_REG_XMM0 = NR_GP_REGISTERS,
	MACH_REG_XMM1,
	MACH_REG_XMM2,
	MACH_REG_XMM3,
	MACH_REG_XMM4,
	MACH_REG_XMM5,
	MACH_REG_XMM6,
	MACH_REG_XMM7,

	NR_FP_REGISTERS,

	/* The above registers are available for register allocator.  */
	NR_REGISTERS = NR_FP_REGISTERS,

	MACH_REG_EBP = NR_REGISTERS,
	MACH_REG_ESP,

	/* The above registers are available for get_fixed_var().  */
	NR_FIXED_REGISTERS,

	/* Either-R**-or-E** variants (for 32/64-bit common code). */
	MACH_REG_xAX = MACH_REG_EAX,
	MACH_REG_xCX = MACH_REG_ECX,
	MACH_REG_xDX = MACH_REG_EDX,
	MACH_REG_xBX = MACH_REG_EBX,
	MACH_REG_xSI = MACH_REG_ESI,
	MACH_REG_xDI = MACH_REG_EDI,
	MACH_REG_xBP = MACH_REG_EBP,
	MACH_REG_xSP = MACH_REG_ESP,

	MACH_REG_UNASSIGNED = CHAR_MAX,
};

#define GPR_VM_TYPE	J_INT

#define NR_CALLER_SAVE_REGS 11
extern enum machine_reg caller_save_regs[NR_CALLER_SAVE_REGS];

const char *reg_name(enum machine_reg reg);

extern uint32_t reg_type_table[NR_REGISTERS];

static inline bool reg_supports_type(enum machine_reg reg, enum vm_type type)
{
	return reg_type_table[reg] & (1UL << type);
}

struct register_state {
	uint64_t			ip;
	union {
		unsigned long		regs[6];
		struct {
			unsigned long	eax;
			unsigned long	ebx;
			unsigned long	ecx;
			unsigned long	edi;
			unsigned long	edx;
			unsigned long	esi;
		};
	};
};

static inline enum vm_type reg_default_type(enum machine_reg reg)
{
	return GPR_VM_TYPE;
}

static inline bool is_xmm_reg(enum machine_reg reg)
{
	return reg >= NR_GP_REGISTERS && reg < NR_FP_REGISTERS;
}

#endif /* X86_REGISTERS_32_H */
